# Changelog

## 0.1.0-alpha.3 (2025-05-25)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/cruzluna/sps-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** api update ([d4be406](https://github.com/cruzluna/sps-python/commit/d4be4060394cefa6861ab7d2f47a09ca73fe9e9c))
* **api:** api update ([727ef04](https://github.com/cruzluna/sps-python/commit/727ef04d5db9b2208489a13dfa65f69278c4007d))
* **api:** api update ([6ea8d2b](https://github.com/cruzluna/sps-python/commit/6ea8d2b9d6cdfb6bca702dfca43dabce1d570fdf))
* **api:** api update ([4cbaffe](https://github.com/cruzluna/sps-python/commit/4cbaffe0d38befcf8167c9910a633ad09cc8f20a))
* **api:** api update ([0ba0463](https://github.com/cruzluna/sps-python/commit/0ba046339f06112df8793862c10e8e7976e76281))
* **api:** api update ([cc10265](https://github.com/cruzluna/sps-python/commit/cc102657eb5ccedc08e62f7ac414cdb189d5f4dd))
* **api:** manual updates to openapi.stainless.yml ([a033c93](https://github.com/cruzluna/sps-python/commit/a033c935ff5ee59dc914d808324b45db44cbacfa))
* **api:** manual updates to stainless config ([39fb04e](https://github.com/cruzluna/sps-python/commit/39fb04e7847da98369b4f8f895cf1ef9c3a73463))


### Chores

* configure new SDK language ([b6faf00](https://github.com/cruzluna/sps-python/commit/b6faf005252c440af7e40e22da9498f36154548f))
* update SDK settings ([9d11cbd](https://github.com/cruzluna/sps-python/commit/9d11cbdcb5e0f10112515e48db56fea1cc9118de))
* update SDK settings ([48b1f52](https://github.com/cruzluna/sps-python/commit/48b1f52463b2de15053b7d6a4a063f87b67a3e1c))

## 0.1.0-alpha.2 (2025-05-24)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/cruzluna/sps-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([6ea8d2b](https://github.com/cruzluna/sps-python/commit/6ea8d2b9d6cdfb6bca702dfca43dabce1d570fdf))
* **api:** api update ([4cbaffe](https://github.com/cruzluna/sps-python/commit/4cbaffe0d38befcf8167c9910a633ad09cc8f20a))
* **api:** api update ([0ba0463](https://github.com/cruzluna/sps-python/commit/0ba046339f06112df8793862c10e8e7976e76281))

## 0.1.0-alpha.1 (2025-05-23)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/cruzluna/sps-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** api update ([cc10265](https://github.com/cruzluna/sps-python/commit/cc102657eb5ccedc08e62f7ac414cdb189d5f4dd))
* **api:** manual updates to openapi.stainless.yml ([a033c93](https://github.com/cruzluna/sps-python/commit/a033c935ff5ee59dc914d808324b45db44cbacfa))

## 0.0.1-alpha.1 (2025-05-23)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/cruzluna/sps-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* configure new SDK language ([b6faf00](https://github.com/cruzluna/sps-python/commit/b6faf005252c440af7e40e22da9498f36154548f))
* update SDK settings ([9d11cbd](https://github.com/cruzluna/sps-python/commit/9d11cbdcb5e0f10112515e48db56fea1cc9118de))
* update SDK settings ([48b1f52](https://github.com/cruzluna/sps-python/commit/48b1f52463b2de15053b7d6a4a063f87b67a3e1c))
